@@ -41,7 +41,7 @@ def deploy_project():
 
 def make_clone():
     """ Creates repository clone on remote server. """
-    run('mkdir -p '+ env.conf.SRC_DIR)
+    run('mkdir -p ' + env.conf.SRC_DIR)
     with cd(env.conf.SRC_DIR):
         with settings(warn_only=True):
             vcs.init()
@@ -61,13 +61,13 @@ def update_django_config(restart=True):
     if restart:
         apache.touch()
 
-def up(branch=None):
+def up(branch=None, before_restart=lambda: None):
     """ Runs vcs ``up`` or ``checkout`` command on server and reloads
     mod_wsgi process. """
     utils.delete_pyc()
     with cd('src/' + env.conf['INSTANCE_NAME']):
         vcs.up(branch)
-    dj_cmd.compress()
+    before_restart()
     apache.touch()
 
 def setup_web_server():
@@ -133,12 +133,12 @@ def undeploy(confirm=True):
         if not console.confirm(message, default=False):
             abort("Aborting.")
 
-    @utils.run_as('root')
+    @utils.run_as_sudo
     def wipe_web():
-        run('rm -f /etc/nginx/sites-enabled/'+env.conf['INSTANCE_NAME'])
-        run('a2dissite ' + env.conf['INSTANCE_NAME'])
-        run('invoke-rc.d nginx reload')
-        run('invoke-rc.d apache2 reload')
+        sudo('rm -f /etc/nginx/sites-enabled/' + env.conf['INSTANCE_NAME'])
+        sudo('a2dissite ' + env.conf['INSTANCE_NAME'])
+        sudo('invoke-rc.d nginx reload')
+        sudo('invoke-rc.d apache2 reload')
 
     wipe_web()
     run('rm -rf %s' % env.conf.SRC_DIR)
