@@ -42,6 +42,7 @@ def install_common_software():
         'lenny': ['libmysqlclient15-dev'],
         'squeeze': ['libmysqlclient-dev'],
         'maverick': ['libmysqlclient-dev'],
+        'lucid': ['libmysqlclient-dev'],
     }
 
     os = utils.detect_os()
@@ -53,13 +54,12 @@ def install_common_software():
     # git and mercurial are outdated in stable Debian Lenny and
     # don't work with some source repositories on github and bitbucket
     vcs_options = {'lenny': '-t lenny-backports'}
-    aptitude_install('mercurial git', vcs_options.get(os, ""))
+    aptitude_install('mercurial git git-core', vcs_options.get(os, ""))
     aptitude_install('bzr', '--without-recommends')
 
     sudo('easy_install -U pip')
     sudo('pip install -U virtualenv')
 
-
 @utils.run_as_sudo
 def setup_backports():
     """ Adds backports repo to apt sources. """
@@ -67,6 +67,8 @@ def setup_backports():
     backports = {
         'lenny': 'http://backports.debian.org/debian-backports lenny-backports main contrib non-free',
         'squeeze': 'http://backports.debian.org/debian-backports squeeze-backports main contrib non-free',
+        'maverick': 'http://archive.ubuntu.com/ubuntu maverick-backports main universe multiverse restricted',
+        'lucid': 'http://archive.ubuntu.com/ubuntu lucid-backports main universe multiverse restricted',
     }
 
     if os not in backports:
@@ -92,19 +94,17 @@ def create_linux_account(pub_key_file, username=None):
 
     username = username or env.conf.USER
 
-    @utils.run_as(username)
-    def setup_pip_conf():
-        from fab_deploy import virtualenv
-        virtualenv.pip_setup_conf()
-
     with (settings(warn_only=True)):
         sudo('adduser %s --disabled-password --gecos ""' % username)
 
-    with cd(env.conf.HOME_DIR):
+    home_dir = utils.get_home_dir(username)
+    with cd(home_dir):
         sudo('mkdir -p .ssh')
         files.append('.ssh/authorized_keys', ssh_key, use_sudo=True)
         sudo('chown -R %s:%s .ssh' % (username, username))
-    setup_pip_conf()
+
+    from fab_deploy import virtualenv
+    virtualenv.pip_setup_conf(username=username)
 
 @utils.run_as('root')
 def create_sudo_linux_account(pub_key_file, username=None):
