@@ -12,8 +12,8 @@ def up(branch):
 
 def push():
     user, host = env.hosts[0].split('@')
-    local('git push ssh://%s/~%s/src/%s/ %s' % (env.hosts[0], user, env.conf.INSTANCE_NAME,
-                                             env.conf.GIT_BRANCH))
+    local('git push --force ssh://%s/~%s/src/%s/ %s' % (env.hosts[0], user,
+        env.conf.INSTANCE_NAME, env.conf.GIT_BRANCH))
 
 def configure():
     pass
