@@ -11,11 +11,16 @@ LAYOUT_OPTIONS = dict(
 )
 
 def foo_site():
-    env.hosts = ['foo@127.0.0.1:2222']
+    env.hosts = ['foo2@127.0.0.1:2222']
     env.conf = dict(
-        DB_PASSWORD = '123',
         VCS = 'git',
         SERVER_NAME = 'foo.example.com',
+
+        SUDO_USER = 'sudouser',
+
+        DB_ROOT_PASSWORD = '123',
+        DB_USER = 'foouser',
+        DB_PASSWORD = 'foo123',
     )
     env.conf.update(LAYOUT_OPTIONS)
     update_env()
