@@ -15,7 +15,7 @@ class FabDeployTest(FabTest):
         update_env()
 
     def setup_conf(self):
-        env.conf = _AttributeDict()
+        env.conf = _AttributeDict(DB_USER='root')
 
     def assertPackageInstalled(self, name):
         self.assertEqual(get_package_state(name), 'i')
