@@ -1,15 +1,16 @@
 from __future__ import absolute_import
 import os
-from fab_deploy.utils import run_as
 from fabric.api import *
-from fabtest import fab, vbox_urlopen
+from fabtest import fab, vbox_urlopen, FabricAbortException
+from fab_deploy.utils import run_as
 from fab_deploy.deploy import deploy_project, push, undeploy
 from fab_deploy.mysql import mysql_create_db
 from fab_deploy.apache import (apache_make_config, apache_make_wsgi,
                                apache_restart, apache_install)
+from fab_deploy.django_commands import command_is_available
 from .base import FabDeployTest
 from ..utils import setup_ssh, setup_sudo
-from ..test_project.fabfile import foo_site, bar_site
+from ..test_project.fabfile import foo_site, bar_site, invalid_site
 from ..test_project2.fabfile import foo_site as foo_site2
 
 def get_file_content(remote_file):
@@ -37,6 +38,10 @@ class FabDeployProjectTest(FabDeployTest):
     def assertResponse(self, url, data):
         self.assertEqual(vbox_urlopen(url).read(), data)
 
+    def assertHttpError(self, url):
+        # FIXME: this should only catch BadStatusLine and urllib2.HttpError
+        self.assertRaises(Exception, vbox_urlopen, url)
+
     def assertNoFile(self, path):
         with(settings(warn_only=True)):
             res = get_file_content(path)
@@ -46,6 +51,18 @@ class FabDeployProjectTest(FabDeployTest):
         with(settings(warn_only=True)):
             self.assertTrue(get_file_content(path))
 
+    def assertCommandAvailable(self, command):
+        result = fab(command_is_available, command)
+        self.assertTrue(result[0])
+
+    def assertCommandNotAvailable(self, command):
+        result = fab(command_is_available, command)
+        self.assertFalse(result[0])
+
+    def assertCommandFails(self, command):
+        self.assertRaises(FabricAbortException, fab,
+                          command_is_available, command)
+
     def setup_conf(self):
         self.cwd = os.getcwd()
         os.chdir(self.project)
@@ -102,22 +119,43 @@ class ApacheSetupTest(FabDeployProjectTest):
 
 class DeployTest(FabDeployProjectTest):
 
+    def assertInstanceWorks(self, instance):
+        url = 'http://%s.example.com/instance/' % instance
+        self.assertResponse(url, instance)
+
+    def assertInstanceDoesntWork(self, instance):
+        url = 'http://%s.example.com/instance/' % instance
+        self.assertHttpError(url)
+
     def test_deploy(self):
+        self.assertCommandFails('syncdb')
+
         # deploy first site
         fab(foo_site)
         fab(deploy_project)
 
-        # first site works
-        self.assertResponse('http://foo.example.com/instance/', 'foo')
+        self.assertCommandAvailable('syncdb')
+        self.assertCommandNotAvailable('syncddb')
+
+        self.assertInstanceWorks('foo')
 
         # deploy second site
         fab(bar_site)
         fab(deploy_project)
 
-        # second site works
-        self.assertResponse('http://bar.example.com/instance/', 'bar')
-        # first site is still available
-        self.assertResponse('http://foo.example.com/instance/', 'foo')
+        self.assertInstanceWorks('bar')
+        self.assertInstanceWorks('foo')
+
+        # deploy improperly configured site
+        fab(invalid_site)
+
+        # config errors should not be silenced
+        self.assertRaises(FabricAbortException, fab, deploy_project)
+
+        # old sites still work
+        self.assertInstanceWorks('bar')
+        self.assertInstanceWorks('foo')
+        self.assertInstanceDoesntWork('invalid')
 
 
 class CustomLayoutDeployTest(FabDeployProjectTest):
@@ -145,7 +183,7 @@ class CustomLayoutDeployTest(FabDeployProjectTest):
         # check that updeploy disables the site
         # TODO: more undeploy tests
         fab(undeploy, confirm=False)
-        self.assertRaises(Exception, vbox_urlopen, url)
+        self.assertHttpError(url)
 
         # deploying project again should be possible
         fab(deploy_project)
